@@ -36,7 +36,6 @@ from astx.callables import (
     Argument,
     Arguments,
     AwaitExpr,
-    Comprehension,
     FunctionAsyncDef,
     FunctionCall,
     FunctionDef,
@@ -45,6 +44,7 @@ from astx.callables import (
     LambdaExpr,
     YieldExpr,
     YieldFromExpr,
+    YieldStmt,
 )
 from astx.classes import (
     ClassDeclStmt,
@@ -53,6 +53,13 @@ from astx.classes import (
     StructDeclStmt,
     StructDefStmt,
 )
+from astx.comprehensions import (
+    Comprehension,
+    ComprehensionClause,
+    GeneratorExpr,
+    ListComprehension,
+    SetComprehension,
+)
 from astx.exceptions import (
     CatchHandlerStmt,
     ExceptionHandlerStmt,
@@ -62,7 +69,11 @@ from astx.exceptions import (
 from astx.flows import (
     AsyncForRangeLoopExpr,
     AsyncForRangeLoopStmt,
+    BreakStmt,
     CaseStmt,
+    ContinueStmt,
+    DoWhileExpr,
+    DoWhileStmt,
     ForCountLoopExpr,
     ForCountLoopStmt,
     ForRangeLoopExpr,
@@ -118,6 +129,7 @@ from astx.operators import (
     AssignmentExpr,
     AugAssign,
     CompareOp,
+    Starred,
     VariableAssignment,
     WalrusOp,
 )
@@ -132,7 +144,10 @@ from astx.packages import (
     Program,
     Target,
 )
-from astx.subscript import SubscriptExpr
+from astx.subscript import (
+    Ellipsis,
+    SubscriptExpr,
+)
 from astx.types import (
     AndOp,
     BinaryOp,
@@ -158,6 +173,7 @@ from astx.types import (
     Integer,
     ListType,
     NandOp,
+    NoneType,
     NorOp,
     NotOp,
     Number,
@@ -194,7 +210,7 @@ def get_version() -> str:
     try:
         return importlib_metadata.version(__name__)
     except importlib_metadata.PackageNotFoundError:  # pragma: no cover
-        return "0.20.0"  # semantic-release
+        return "0.22.1"  # semantic-release
 
 
 __all__ = [
@@ -215,6 +231,7 @@ __all__ = [
     "BoolBinaryOp",
     "BoolUnaryOp",
     "Boolean",
+    "BreakStmt",
     "CaseStmt",
     "CatchHandlerStmt",
     "ClassDeclStmt",
@@ -225,12 +242,17 @@ __all__ = [
     "Complex32",
     "Complex64",
     "Comprehension",
+    "ComprehensionClause",
+    "ContinueStmt",
     "DataType",
     "DataTypeOps",
     "Date",
     "DateTime",
     "DeleteStmt",
     "DictType",
+    "DoWhileExpr",
+    "DoWhileStmt",
+    "Ellipsis",
     "EnumDeclStmt",
     "ExceptionHandlerStmt",
     "Expr",
@@ -249,6 +271,7 @@ __all__ = [
     "FunctionDef",
     "FunctionPrototype",
     "FunctionReturn",
+    "GeneratorExpr",
     "GotoStmt",
     "Identifier",
     "IfExpr",
@@ -264,6 +287,7 @@ __all__ = [
     "Int64",
     "Integer",
     "LambdaExpr",
+    "ListComprehension",
     "ListType",
     "Literal",
     "LiteralBoolean",
@@ -299,6 +323,7 @@ __all__ = [
     "MutabilityKind",
     "NamedExpr",
     "NandOp",
+    "NoneType",
     "NorOp",
     "NotOp",
     "Number",
@@ -308,9 +333,11 @@ __all__ = [
     "ParenthesizedExpr",
     "Program",
     "ScopeKind",
+    "SetComprehension",
     "SetType",
     "SignedInteger",
     "SourceLocation",
+    "Starred",
     "StatementType",
     "String",
     "StructDeclStmt",
@@ -344,6 +371,7 @@ __all__ = [
     "XorOp",
     "YieldExpr",
     "YieldFromExpr",
+    "YieldStmt",
     "base",
     "blocks",
     "callables",
