@@ -106,6 +106,7 @@ class ASTKind(Enum):
     AssignmentExprKind = -303
     AugmentedAssignKind = -304
     CompareOpKind = -305
+    StarredKind = -306
 
     # functions
     PrototypeKind = -400
@@ -118,6 +119,9 @@ class ASTKind(Enum):
     YieldExprKind = -407
     YieldFromExprKind = -408
     ComprehensionKind = -409
+    ListComprehensionKind = -410
+    SetComprehensionKind = -411
+    YieldStmtKind = -412
 
     # control flow
     IfStmtKind = -500
@@ -134,6 +138,11 @@ class ASTKind(Enum):
     WithStmtKind = -512
     AsyncRangeLoopStmtKind = -513
     AsyncRangeLoopExprKind = -514
+    DoWhileStmtKind = -515
+    DoWhileExprKind = -516
+    GeneratorExprKind = -517
+    BreakStmtKind = -518
+    ContinueStmtKind = -519
 
     # data types
     NullDTKind = -600
@@ -182,6 +191,7 @@ class ASTKind(Enum):
 
     # subscrpts
     SubscriptExprKind = -1000
+    EllipsisKind = -1001
 
     # exceptions
     ThrowStmtKind = -1100
