@@ -8,12 +8,15 @@ from public import public
 
 from astx.base import (
     ASTNodes,
+    ASTType,
+    ReprStruct,
 )
-from astx.types import ReprStruct
+from astx.tools.typing import typechecked
 
 
 @public
-class Block(ASTNodes):
+@typechecked
+class Block(ASTNodes[ASTType]):
     """The AST tree."""
 
     def get_struct(self, simplified: bool = False) -> ReprStruct:
@@ -23,7 +26,7 @@ class Block(ASTNodes):
         for node in self.nodes:
             block_nodes.append(node.get_struct(simplified))
 
-        key = "BLOCK"
+        key = f"BLOCK[{self.name}-{id(self)}]"
         value = cast(ReprStruct, block_nodes)
 
         return self._prepare_struct(key, value, simplified)
