@@ -95,13 +95,13 @@ class Arguments(ASTNodes[Argument]):
 class FunctionCall(DataType):
     """AST class for function call."""
 
-    fn: FunctionDef
+    fn: str
     args: Iterable[DataType]
     type_: DataType = AnyType()
 
     def __init__(
         self,
-        fn: FunctionDef,
+        fn: FunctionDef | str,
         args: Iterable[DataType],
         type_: DataType = AnyType(),
         loc: SourceLocation = NO_SOURCE_LOCATION,
@@ -109,7 +109,7 @@ class FunctionCall(DataType):
     ) -> None:
         """Initialize the Call instance."""
         super().__init__(loc=loc, parent=parent)
-        self.fn = fn
+        self.fn = fn if not isinstance(fn, FunctionDef) else fn.name
         self.args = args
         self.kind = ASTKind.CallKind
         self.type_ = type_
@@ -126,7 +126,7 @@ class FunctionCall(DataType):
         for node in self.args:
             call_params.append(node.get_struct(simplified))
 
-        key = f"FUNCTION-CALL[{self.fn.name}]"
+        key = f"FUNCTION-CALL[{self.fn}]"
         value = cast(
             ReprStruct,
             {
@@ -388,6 +388,47 @@ class YieldExpr(Expr):
         return self._prepare_struct(key, value, simplified)
 
 
+@public
+@typechecked
+class YieldStmt(StatementType):
+    """AST class for yield statement."""
+
+    value: Optional[Expr]
+
+    def __init__(
+        self,
+        value: Optional[Expr] = None,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
+    ) -> None:
+        """Initialize the YieldStmt instance.
+
+        Args:
+            value: The expression to yield (optional)
+            loc: Source location of the statement
+            parent: Parent AST node
+        """
+        super().__init__(loc=loc, parent=parent)
+        self.value = value
+        self.kind = ASTKind.YieldStmtKind
+
+    def __str__(self) -> str:
+        """Return a string representation of the object."""
+        return (
+            f"YieldStmt[{self.value}]"
+            if self.value is not None
+            else "YieldStmt"
+        )
+
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
+        """Return the AST structure of the object."""
+        key = f"YIELD-STMT[{id(self)}]" if simplified else "YIELD-STMT"
+        value = (
+            self.value.get_struct(simplified) if self.value is not None else {}
+        )
+        return self._prepare_struct(key, value, simplified)
+
+
 @public
 @typechecked
 class YieldFromExpr(Expr):
@@ -415,46 +456,3 @@ class YieldFromExpr(Expr):
         key = "YIELDFROM-EXPR"
         value = self.value.get_struct(simplified)
         return self._prepare_struct(key, value, simplified)
-
-
-@public
-@typechecked
-class Comprehension(Expr):
-    """AST node for generic comprehensions."""
-
-    target: Expr
-    iterable: Expr
-    conditions: list[Expr]
-    is_async: bool
-
-    def __init__(
-        self,
-        target: Expr,
-        iterable: Expr,
-        conditions: Optional[list[Expr]] = None,
-        is_async: bool = False,
-        loc: SourceLocation = NO_SOURCE_LOCATION,
-        parent: Optional[ASTNodes] = None,
-    ) -> None:
-        super().__init__(loc=loc, parent=parent)
-        self.target = target
-        self.iterable = iterable
-        self.conditions = conditions if conditions is not None else []
-        self.is_async = is_async
-        self.kind = ASTKind.ComprehensionKind
-
-    def __str__(self) -> str:
-        """Return a string representation of the object."""
-        return f"COMPREHENSION[is_async={self.is_async}]"
-
-    def get_struct(self, simplified: bool = False) -> ReprStruct:
-        """Return the AST structure of the object."""
-        value: ReprStruct = {
-            "target": self.target.get_struct(simplified),
-            "iterable": self.iterable.get_struct(simplified),
-            "conditions": [
-                cond.get_struct(simplified) for cond in self.conditions
-            ],
-        }
-        key = f"{self}" if not simplified else f"{self}#{id(self)}"
-        return self._prepare_struct(key, value, simplified)
