@@ -472,6 +472,56 @@ class AsyncForRangeLoopExpr(Expr):
         return self._prepare_struct(key, value, simplified)
 
 
+@public
+@typechecked
+class BreakStmt(StatementType):
+    """AST class for break statement."""
+
+    def __init__(
+        self,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
+    ) -> None:
+        """Initialize the BreakStmt instance."""
+        super().__init__(loc=loc, parent=parent)
+        self.kind = ASTKind.BreakStmtKind
+
+    def __str__(self) -> str:
+        """Return a string representation of the object."""
+        return "BreakStmt"
+
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
+        """Return the AST structure of the object."""
+        key = "BREAK-STMT"
+        value: DictDataTypesStruct = {}
+        return self._prepare_struct(key, value, simplified)
+
+
+@public
+@typechecked
+class ContinueStmt(StatementType):
+    """AST class for continue statement."""
+
+    def __init__(
+        self,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
+    ) -> None:
+        """Initialize the ContinueStmt instance."""
+        super().__init__(loc=loc, parent=parent)
+        self.kind = ASTKind.ContinueStmtKind
+
+    def __str__(self) -> str:
+        """Return a string representation of the object."""
+        return "ContinueStmt"
+
+    def get_struct(self, simplified: bool = False) -> ReprStruct:
+        """Return the AST structure of the object."""
+        key = "CONTINUE-STMT"
+        value: DictDataTypesStruct = {}
+        return self._prepare_struct(key, value, simplified)
+
+
 @public
 @typechecked
 class WhileStmt(StatementType):
@@ -691,3 +741,49 @@ class GotoStmt(StatementType):
         key = f"GOTO-STMT[{self.label.value}]"
         value: DictDataTypesStruct = {}
         return self._prepare_struct(key, value, simplified)
+
+
+@public
+@typechecked
+class DoWhileStmt(WhileStmt):
+    """AST class for `do-while` statement."""
+
+    def __init__(
+        self,
+        condition: Expr,
+        body: Block,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
+    ) -> None:
+        """Initialize the DoWhileStmt instance."""
+        super().__init__(
+            condition=condition, body=body, loc=loc, parent=parent
+        )
+        self.kind = ASTKind.DoWhileStmtKind
+
+    def __str__(self) -> str:
+        """Return a string representation of the object."""
+        return f"DoWhileStmt[{self.condition}]"
+
+
+@public
+@typechecked
+class DoWhileExpr(WhileExpr):
+    """AST class for `do-while` expression."""
+
+    def __init__(
+        self,
+        condition: Expr,
+        body: Block,
+        loc: SourceLocation = NO_SOURCE_LOCATION,
+        parent: Optional[ASTNodes] = None,
+    ) -> None:
+        """Initialize the DoWhileExpr instance."""
+        super().__init__(
+            condition=condition, body=body, loc=loc, parent=parent
+        )
+        self.kind = ASTKind.DoWhileExprKind
+
+    def __str__(self) -> str:
+        """Return a string representation of the object."""
+        return f"DoWhileExpr[{self.condition}]"
