@@ -8,9 +8,9 @@ except ImportError:
     from typing_extensions import TypeAlias
 
 from astx.base import DataType
-from astx.callables import Function
+from astx.callables import FunctionDef
 from astx.variables import Variable
 
 __all__ = ["NamedExpr"]
 
-NamedExpr: TypeAlias = Union[DataType, Function, Variable]
+NamedExpr: TypeAlias = Union[DataType, FunctionDef, Variable]
