@@ -14,9 +14,11 @@ from typing import Optional, Type
 from public import public
 
 from astx.mixes import NamedExpr
+from astx.tools.typing import typechecked
 
 
 @public
+@typechecked
 class ScopeNodeBase:
     """ScopeNodeBase is the base used for the nodes (levels) in the scope."""
 
@@ -37,6 +39,7 @@ class ScopeNodeBase:
 
 
 @public
+@typechecked
 class ScopeNode(ScopeNodeBase):
     """Scope node organize the scope in different levels in the stack."""
 
@@ -44,6 +47,7 @@ class ScopeNode(ScopeNodeBase):
 
 
 @public
+@typechecked
 class Scope:
     """Organize the ASTx objects according to the scope."""
 
@@ -110,6 +114,7 @@ class Scope:
 
 
 @public
+@typechecked
 class SymbolTable:
     """Symbol Table for ASTx."""
 
